@@ -40,8 +40,8 @@ def _validate_base_directory():
 def _lint_directory(logger):
     has_error = False
     cwd = Path.cwd()
-    if not _correct_classname(cwd, logger):
-        has_error = True
+    # if not _correct_classname(cwd, logger):
+    #     has_error = True
 
     for path in cwd.glob("**"):
         relative_path = path.relative_to(cwd)
@@ -58,29 +58,29 @@ def _lint_directory(logger):
 def _check_methods():  # Check they've got the right methods on their class
     return None
 
+# TODO CHECK for subclass
+# def _correct_classname(cwd, logger):
+#     with open("idk.json", "r") as config_file:
+#         config = json.load(config_file)
+#         print(f"The path is {Path.cwd()}")
+#         sys.path.insert(0, str(Path.cwd()))
+#         try:
+#             cls = __import__(config["insight_file"].replace('.py', ''),
+#                              fromlist=[config["insight_class"]])
+#         except Exception as e:
+#             logger.error(
+#                 f"Couldn't import {config['insight_class']} from {config['insight_file']}:\n"
+#             )
+#             raise e
 
-def _correct_classname(cwd, logger):
-    with open("idk.json", "r") as config_file:
-        config = json.load(config_file)
-        print(f"The path is {Path.cwd()}")
-        sys.path.insert(0, str(Path.cwd()))
-        try:
-            cls = __import__(config["insight_file"].replace('.py', ''),
-                             fromlist=[config["insight_class"]])
-        except Exception as e:
-            logger.error(
-                f"Couldn't import {config['insight_class']} from {config['insight_file']}:\n"
-            )
-            raise e
+#         cls = getattr(cls, config['insight_class'])
 
-        cls = getattr(cls, config['insight_class'])
-
-        if not issubclass(cls, insight.InsightGenerator):
-            logger.error(
-                f"{config['insight_class']} must be a subclass of \"idk.insight.InsightGenerator\""
-            )
-            return False
-    return True
+#         if not issubclass(cls, insight.InsightGenerator):
+#             logger.error(
+#                 f"{config['insight_class']} must be a subclass of \"idk.insight.InsightGenerator\""
+#             )
+#             return False
+#     return True
 
 
 def run_cmd(cmd, **kwargs):
